'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _amazonCognitoIdentityJs = require('amazon-cognito-identity-js');

var _error = require('../error');

var _session = require('../session');

var _session2 = _interopRequireDefault(_session);

var _logger = require('../logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var logger = new _logger2.default('Cognito.UserPool');

/**
* Cognito User Pool client
* @class
*/

var UserPool = function () {
    /**
    * @constructor
    * @param {object} config - User pool config
    <pre>
    {
        user_pool_id: ...,
        client_id: ...
    }
    </pre>
    */
    function UserPool(config) {
        _classCallCheck(this, UserPool);

        if (!config) {
            throw new _error.MissingParameterError('config');
        }
        if (!config.user_pool_id) {
            throw new _error.MissingParameterError('config.user_pool_id');
        }
        if (!config.client_id) {
            throw new _error.MissingParameterError('config.client_id');
        }

        this.pool = new _amazonCognitoIdentityJs.CognitoUserPool({
            UserPoolId: config.user_pool_id,
            ClientId: config.client_id
        });
    }

    _createClass(UserPool, [{
        key: 'signUp',
        value: function signUp(username, password, attributes, callback) {
            if (!callback) {
                logger.warn('No callback for signUp');
            }

            var attribute_list = Object.keys(attributes).map(function (key) {
                return {
                    Name: key,
                    Value: attributes[key]
                };
            });

            this.pool.signUp(username, password, attribute_list, null, function (err, data) {
                if (err) {
                    callback && callback(err);
                } else {
                    var user = data.user;
                    logger.debug('Sign up success: ' + user.getUsername());
                    logger.debug(user);
                    _session2.default.set('signUp.user', user);
                    callback && callback(null, user);
                }
            });
        }
    }]);

    return UserPool;
}();

exports.default = UserPool;
;