import {
    CognitoUserPool,
    CognitoUserAttribute,
    AuthenticationDetails,
    CognitoUser
} from 'amazon-cognito-identity-js';

import { MissingParameterError } from '../error';
import Session from '../session';
import Logger from '../logger';

const logger = new Logger('Cognito.UserPool');

/**
* Cognito User Pool client
* @class
*/
export default class UserPool {
    /**
    * @constructor
    * @param {object} config - User pool config
    <pre>
    {
        user_pool_id: ...,
        client_id: ...
    }
    </pre>
    */
    constructor(config) {
        if (!config) { throw new MissingParameterError('config'); }
        if (!config.user_pool_id) { throw new MissingParameterError('config.user_pool_id'); }
        if (!config.client_id) { throw new MissingParameterError('config.client_id'); }

        this.pool = new CognitoUserPool({
            UserPoolId: config.user_pool_id,
            ClientId: config.client_id
        });
    }

    signUp(username, password, attributes, callback) {
        if (!callback) { logger.warn('No callback for signUp'); }

        const attribute_list = Object.keys(attributes)
            .map(function(key) {
                return {
                    Name: key,
                    Value: attributes[key]
                };
            });

        this.pool.signUp(username, password, attribute_list, null, function(err, data) {
            if (err) {
                callback && callback(err);
            } else {
                const user = data.user;
                logger.debug('Sign up success: ' + user.getUsername());
                logger.debug(user);
                Session.set('signUp.user', user);
                callback && callback(null, user);
            }
        });
    }
};
