const LOG_LEVELS = {
    ERROR: 1,
    WARN: 2,
    INFO: 3,
    DEBUG: 4
};

/**
* Write logs
* @class Logger
*/
export default class Logger {
    /**
    * @constructor
    * @param {string} name - Name of the logger
    */
    constructor(name, level) {
        this.name = name;
        this.level = level || 'DEBUG';
    }

    /**
    * Write log
    * @method
    * @memeberof Logger
    * @param {string|object} msg - Logging message or object
    * @param {string} type - log type, default INFO
    */
    log(msg, type) {
        type = type || 'INFO';

        if (LOG_LEVELS[this.level] < LOG_LEVELS[type]) { return; }

        if (typeof msg === 'object') {
            console.log('[' + type + '] ' + this.name + ' - ');
            console.log(msg);
        } else {
            console.log('[' + type + '] ' + this.name + ' - ' + msg);
        }
    }

    /**
    * Write INFO log
    * @method
    * @memeberof Logger
    * @param {string|object} msg - Logging message or object
    */
    info(msg) { this.log(msg, 'INFO'); }

    /**
    * Write WARN log
    * @method
    * @memeberof Logger
    * @param {string|object} msg - Logging message or object
    */
    warn(msg) { this.log(msg, 'WARN'); }

    /**
    * Write ERROR log
    * @method
    * @memeberof Logger
    * @param {string|object} msg - Logging message or object
    */
    error(msg) { this.log(msg, 'ERROR'); }

    /**
    * Write DEBUG log
    * @method
    * @memeberof Logger
    * @param {string|object} msg - Logging message or object
    */
    debug(msg) { this.log(msg, 'DEBUG'); }
};
